@@ -1,5 +1,5 @@
-//go:generate counterfeiter -o fakes/fake_registry_client.go ../../../../vendor/github.com/operator-framework/operator-registry/pkg/client/client.go Interface
-//go:generate counterfeiter -o ../../../fakes/fake_resolver.go . Resolver
+//go:generate go run github.com/maxbrunsfeld/counterfeiter/v6 -o fakes/fake_registry_interface.go ../../../../vendor/github.com/operator-framework/operator-registry/pkg/client/client.go Interface
+//go:generate go run github.com/maxbrunsfeld/counterfeiter/v6 -o ../../../fakes/fake_resolver.go . Resolver
 package resolver
 
 import (
@@ -96,7 +96,7 @@ func (r *OperatorsV1alpha1Resolver) ResolveSteps(namespace string, sourceQuerier
 		if op.Bundle() != nil {
 			bundleSteps, err := NewStepResourceFromBundle(op.Bundle(), namespace, op.Replaces(), op.SourceInfo().Catalog.Name, op.SourceInfo().Catalog.Namespace)
 			if err != nil {
-				return nil, nil, fmt.Errorf("failed to turn bundle into steps")
+				return nil, nil, fmt.Errorf("failed to turn bundle into steps: %s", err.Error())
 			}
 			for _, s := range bundleSteps {
 				steps = append(steps, &v1alpha1.Step{
